@@ -603,8 +603,20 @@ FlashGotDM.prototype = {
       return downloadDir.path;
     }
     
+    var urlLabel = links.length > 1
+      ? links.length + " @ " +
+      (function() {
+        var ll = links.map(function(l) {
+          return l.href.match(/^[\w-]+:\/*([^\/]+)/)[1];
+        }).sort(); // extract and sort domains
+        for (var j = ll.length; j-- > 1;) // remove dupes
+          if (ll[j - 1] == ll[j]) ll.splice(j, 1);
+        return ll;
+      })().join(", ")
+      : links[0].href.replace(/^[\w-]+:\/*([^\/]+\/).*?([^\/\?]+)(?:$|\?.*)/, '$1.../$2');
+    
     var params = {
-      title: "FlashGot (" + this.name.replace(/[\(\)]/g, "") + ")",
+      title: "FlashGot (" + this.name.replace(/[\(\)]/g, "") + ") " + urlLabel,
       initialDir: initialDir,
       choosenDir: null
     }
@@ -1856,7 +1868,7 @@ FlashGotDM.initDMS = function() {
       this.thunderDelay = 1000;
       return;
     } catch(e) {}
-    postCall;
+    postCall();
   }
   new FlashGotDM("Thunder (Old)");
 
@@ -2007,8 +2019,14 @@ FlashGotDM.initDMS = function() {
       pp.cookies.push(this.getCookie(l, links));
     }
     
-    if ("fname" in links[0])
-      pp.fnames = links.map(function(l) { return l.fname; });
+    if (links.some(function(l) { return "fname" in l }))
+      pp.fnames = links.map(function(l) { return l.fname || ''; });
+    
+    if (links.some(function(l) { return "pwd" in l }))
+      pp.arcpass = links.map(function(l) { return l.pwd || ''; });
+    
+    if (links.some(function(l) { return "userPass" in l }))
+      pp.httpauth = links.map(function(l) { return l.userPass || '' });
     
     const data = [
       "autostart=" + (this.getPref("autostart", true) ? "1" : "0"),
@@ -2517,7 +2535,7 @@ FlashGotDM.initDMS = function() {
               .QueryInterface(CI.nsIWebProgressListener);
           
           persist.saveURI(uri, l.cacheKey || null,
-                  links.refURI, postData, null, file);
+                  links.refURI, l.postStream || postData || null, null, file);
         } catch (e) {
           fg.log("Skipping link " + l.href + ": " + e);
         }
