@@ -1,6 +1,6 @@
 /***** BEGIN LICENSE BLOCK *****
     FlashGot - a Firefox extension for external download managers integration
-    Copyright (C) 2004-2011 Giorgio Maone - g.maone@informaction.com
+    Copyright (C) 2004-2007 Giorgio Maone - g.maone@informaction.com
     
     contributors:
     Max Velasques (wxDownload Fast support)
@@ -197,6 +197,7 @@ using namespace std;
 class DMSAddUrlFamily :
 	public DMSupportCOM
 {
+protected:
 	void dispatch(const DownloadInfo *downloadInfo)
 	{
 		CookieManager cm(downloadInfo);
@@ -239,21 +240,6 @@ public:
 
 };
 
-class DMSFlashGet2 :
-	public DMSAddUrlFamily
-{
-
-protected:
-	
-	const char * getProgId() { return "FG2CatchUrl.Netscape"; }
-	
-public:
-	
-	const char * getName() { return "FlashGet 2"; }
-
-};
-
-
 class DMSFlashGet2X :
 	public DMSupportCOM
 {
@@ -271,26 +257,34 @@ public:
 		CookieManager cm(downloadInfo);
 		HELPER(h);
 		int linksCount=downloadInfo->linksCount;
-		if(linksCount>0) try
+		if( linksCount >0 ) try
 		{
 			
 			if(linksCount<2) {
 				LinkInfo link = downloadInfo->links[0];
-				VARIANT v[6];
+				VARIANT v[7];
 				try
 				{
-				
-					v[5].vt = v[4].vt = v[3].vt = v[2].vt = v[1].vt = v[0].vt = VT_BSTR;
-					v[5].bstrVal = link.url;
-					v[4].bstrVal = link.comment.length() > 0 ? link.url : link.comment;
-					v[3].bstrVal = downloadInfo->referer;
-					v[2].bstrVal = SysAllocString(L"FlashGet3");
-					v[1].bstrVal = link.cookie;
-					v[0].bstrVal = SysAllocString(L"0");
-					h.invoke("AddUrlEx", v, 6);
+					v[6].vt = v[5].vt = v[4].vt = v[3].vt = v[2].vt = v[1].vt = v[0].vt = VT_BSTR;
+					v[6].bstrVal = link.url;
+					v[5].bstrVal = link.comment.length() > 0 ? link.url : link.comment;
+					v[4].bstrVal = downloadInfo->referer;
+					v[3].bstrVal = SysAllocString(L"FlashGet3");
+					v[2].bstrVal = link.cookie;
+					v[1].bstrVal = SysAllocString(L"0");
+					v[0].bstrVal = SysAllocString(L"3");
+					try 
+					{
+						h.invoke("AddUrlEx", v, 7); // v >= 3.7
+					} catch(...)
+					{
+						// shift left and cut at 6
+						for (size_t j = 0; j < 6;) v[j].bstrVal = v[++j].bstrVal; 
+						h.invoke("AddUrlEx", v, 6); // v < 3.7
+					}
 				} catch(...)
 				{
-                    v[2].bstrVal = SysAllocString(L"FlashGet");
+                    v[2].bstrVal = SysAllocString(L"FlashGet"); // v < 3
 					try
 					{
 						h.invoke("AddUrlEx", v, 6);
@@ -352,10 +346,30 @@ public:
 	}
 };
 
+class DMSFlashGet2 :
+	public DMSAddUrlFamily
+{
 
+protected:
+	
+	const char * getProgId() { return "FG2CatchUrl.Netscape"; }
+	
+public:
+	
+	const char * getName() { return "FlashGet 2"; }
 
-
-
+	void dispatch(const DownloadInfo *downloadInfo)
+	{
+		try
+		{
+		  DMSAddUrlFamily::dispatch(downloadInfo);
+		} catch(...)
+		{
+			DMSFlashGet2X dms;
+			dms.dispatch(downloadInfo);
+		}
+	}
+};
 
 
 class DMSFreeDownloadManager :
@@ -1591,127 +1605,40 @@ public:
 };
 
 
-
-
-
 // [END DOWNLOAD MANAGER SUPPORT CLASSES]
 
-
-typedef struct _DMSNode {
-	unsigned int id;
-	DMSupport *dms;
-	_DMSNode *prev;
-} DMSNode;
-
-
-
-class DMSFactory 
-{
-private:
-	static DMSFactory *instance;
-	DMSNode *last;
-	DMSupport *add(DMSupport *dms) {
-		if(!last) {
-			(last=new DMSNode())->prev=NULL;
-			last->id=1;
-		} else {
-			DMSNode *newNode=new DMSNode();
-			newNode->prev=last;
-			newNode->id=last->id << 1;
-			last=newNode;
-		}
-		return last->dms=dms;
-	}
-
-	DMSFactory() : last(NULL) {
-
-
-		add(new DMSBitComet());
-		add(new DMSDownloadAcceleratorPlus());
-		add(new DMSDownloadMaster());
-		add(new DMSFlashGet());
-		add(new DMSFlashGet2());
-		add(new DMSFlashGet2X());
-		add(new DMSFreeDownloadManager());
-		add(new DMSFreshDownload());
-		add(new DMSGetRight());
-		add(new DMSGigaGet());
-		add(new DMSHiDownload());
-		add(new DMSInstantGet());
-		add(new DMSInternetDownloadAccelerator());
-		add(new DMSInternetDownloadManager());
-		add(new DMSLeechGet2002());
-		add(new DMSLeechGet());
-		add(new DMSMass_Downloader());
-		add(new DMSNetAnts());
-		add(new DMSNet_Transport());
-		add(new DMSNet_Transport2());
-		add(new DMSOrbit());
-		add(new DMSReGet());
-		add(new DMSStarDownloader());
-		add(new DMSTrueDownloader());
-		add(new DMSThunder());
-		add(new DMSThunderOld());
-		add(new DMSWellGet());
-		add(new DMSwxDownloadFast());
-
-}
-
-public:
-	
-	static DMSFactory *getInstance() {
-		return instance?instance:instance=new DMSFactory();		
-	}
-	
-	
-	DMSupport *getDMS(char *name) {
-		DMSNode *cursor=last;
-		for(; cursor && strcmp(cursor->dms->getName(),name); cursor=cursor->prev);
-		return cursor 
-			?cursor->dms
-			:NULL;	
-	}
-	
-	unsigned int checkAll() {
-		unsigned int retVal=0;
-		fprintf(stdout,"FlashGot Win Bridge %s\r\n",VERSION);
-		FGCOMGuard::addClient();
-		for(DMSNode *cursor=last; cursor; cursor=cursor->prev) {
-			try {
-				fprintf(stdout,"%s|",cursor->dms->getName());
-				cursor->dms->check();
-				fprintf(stdout,"OK\n");
-				continue;
-			} catch(_com_error ce) {
-				fprintf(stdout,"BAD\nCOM error: %s\n", ce.ErrorMessage());
-			} catch(...) {
-				fprintf(stdout,"BAD\nunexpected unknown error!\n");
-			}
-			retVal |= cursor->id;
-		}
-		FGCOMGuard::removeClient();
-		return retVal;
-	}
-
-
-
-	~DMSFactory() {
-		DMSNode *cursor=last;
-		while( cursor ) {
-			delete cursor->dms;
-			last=cursor;
-			cursor=last->prev;
-			delete last;
-		}
-	}
-};
 DMSFactory * DMSFactory::instance=NULL;
-
-
-
-
-
-
+void DMSFactory::registerAll()
+{
+	add(new DMSBitComet());
+	add(new DMSDownloadAcceleratorPlus());
+	add(new DMSDownloadMaster());
+	add(new DMSFlashGet());
+	add(new DMSFlashGet2());
+	add(new DMSFlashGet2X());
+	add(new DMSFreeDownloadManager());
+	add(new DMSFreshDownload());
+	add(new DMSGetRight());
+	add(new DMSGigaGet());
+	add(new DMSHiDownload());
+	add(new DMSInstantGet());
+	add(new DMSInternetDownloadAccelerator());
+	add(new DMSInternetDownloadManager());
+	add(new DMSLeechGet2002());
+	add(new DMSLeechGet());
+	add(new DMSMass_Downloader());
+	add(new DMSNetAnts());
+	add(new DMSNet_Transport());
+	add(new DMSNet_Transport2());
+	add(new DMSOrbit());
+	add(new DMSReGet());
+	add(new DMSStarDownloader());
+	add(new DMSTrueDownloader());
+	add(new DMSThunder());
+	add(new DMSThunderOld());
+	add(new DMSWellGet());
+	add(new DMSwxDownloadFast());
+}
 
 
 
