@@ -203,11 +203,19 @@ RedirectContext.prototype = {
    
     
     function chooselinks_com(l, context) {
-      if (/^https?:\/\/(?:[^\/]*\w\.)?(?:(?:chooselink|re-links)\.com|linksafe\.me)\//i.test(l.href))
+      if (/^https?:\/\/(?:[^\/]*\w\.)?(?:(?:chooselink|re-links)\.com|linksafe\.me)\//i.test(l.href)) {
+        /* old style, let's keep it around just in case
         context.load(l.href, function(req) {
           var m = req.responseText.match(/\blocation(?:\.href)?\s*=\s*['"](https?:\/\/[^"']+)/);
           if (m) context.change(l, m[1], "chooselinks_com");
         });
+        */
+        context.start();
+        context.sniffRedir(l.href, function(u) {
+          context.change(l, u, 'chooselinks_com');
+          context.done();
+        });
+      }
     },
     
     function filesonic_com(l, context) {
