@@ -677,9 +677,7 @@ var gFlashGot = {
     }
     if(doc == null) return [];
     const allLinks = [];
-    const lm = gFlashGotService.lookupMethod;
-
-
+    
     function wrapAndFilter(newL, l) {
       const href = l.src;
       if (!href) return null;
@@ -699,25 +697,25 @@ var gFlashGot = {
         newL.href =  href 
       }
       
-      const ga = lm(l, "getAttribute");
-      var des = ga("alt") || ga("title") || href.substring(href.lastIndexOf("/") + 1);
-      var w, h;
-      (w = ga("width")) && (h = ga("height")) && (des += " (" + w + "," + h + ")");
 
+      var des = l.alt || l.title || href.substring(href.lastIndexOf("/") + 1);
+      var w, h;
+      if ((w = l.width) && (h = l.height))
+        des += " (" + w + "," + h + ")";
+        
       newL.description = des;
 
       return filter(newL, l);
     }
     
     function filterLinks(elems, filter, tagName) {
-      const wrap = tagName == "A";
+      const wrap = tagName === "A";
       try {
         if(elems) {
           var l, newL;
-          const e_item = lm(elems,"item");
-          for(var j = 0, len = lm(elems,"length")(); j < len; j++) {
-            l = e_item(j);
-            newL = wrap ? gFlashGot._wrapAnchor(l, lm) : { tagName: tagName };
+          for(var j = 0, len = elems.length; j < len; j++) {
+            l = elems[j];
+            newL = wrap ? gFlashGot._wrapAnchor(l) : { tagName: tagName };
             if(newL && filter(newL, l)) {
               allLinks[allLinks.length] = newL;
             }
@@ -767,7 +765,6 @@ var gFlashGot = {
   },
   
   grabSelectedTextFields: function(selection, justCheck) {
-    const lm = gFlashGotService.lookupMethod;
     const doc = this.srcDocument;
     var ff, f, j;
     const vv = [];
@@ -778,13 +775,13 @@ var gFlashGot = {
         try {
           if(selection && selection.containsNode(f, true)) {
             if(justCheck) return true;
-            vv.push(lm(f, "value")());
+            vv.push(f.value);
           }
           else {
-            selStart = lm(f, "selectionStart")(), selEnd = lm(f, "selectionEnd")();
+            selStart = f.selectionStart, selEnd = f.selectionEnd;
             if(selStart < selEnd) {
               if(justCheck) return true;
-              vv.push(lm(f, "value")()).substring(selStart, selEnd);
+              vv.push(f.value.substring(selStart, selEnd));
             }
           }
         } catch(e) {}
@@ -817,7 +814,7 @@ var gFlashGot = {
     // text links detection
     m = selString.match(
       /\b(?:(?:h.{2}p|ftp|mms|ed2k|rtsp|rtmpe?):\/\/|[a-z]+[a-z\d]+\.[a-z\d\-\.]+\/|magnet:\?)[^\s]*/gi);
-    delete selString;
+    selString = "";
     var j, k;
     if(m) {
       var descMap = null;
@@ -850,10 +847,11 @@ var gFlashGot = {
     
     if(pwd) {
       var des;
-      pwd = " pw: " + pwd;
+      var pwdDes = " pw: " + pwd;
       for(j = links.length; j-- > 0;) {
         des = links[j].description || "";
-        links[j].description = des.substring(0, 4) == "http" ? pwd : des.concat(pwd);
+        links[j].pwd = pwd;
+        links[j].description = des.substring(0, 4) == "http" ? pwdDes : des.concat(pwdDes);
       }
     }
     return links;
@@ -863,29 +861,26 @@ var gFlashGot = {
     return link.href && /^(?:\w+:\/\/.*|javascript:.*http|magnet:)/i.test(link.href) && !/^(mailto|news|file|data):/i.test(link.href);
   }
 ,
-  _wrapAnchor: function(node, lm) {
+  _wrapAnchor: function(node) {
     var isAnchor = (node instanceof HTMLAnchorElement);
     if(isAnchor || node instanceof HTMLAreaElement) {
-      var d;
-      var href = lm(node, "href")();
+      var href = node.href;
       if(href) return { 
         href: href,
         tagName: "A",
-        getElementsByTagName: lm(node, "getElementsByTagName"),
+        getElementsByTagName: function(n) { return node.getElementsByTagName(n) },
         description: isAnchor 
-          ? (d = lm(node,"title")()) || 
-            (d = lm(node, "innerHTML")()) && d.replace(/<[^>]*>/g, "") 
-          : (d = (lm(node, "alt")() || lm(node, "title")())) 
+          ? node.title || node.textContent
+          : node.alt || node.title 
         };
     }
     return null;
   }
 ,
   findLinkAsc: function(node) {
-     const lm = gFlashGotService.lookupMethod;
      var anchor;
      while(node) {
-      anchor = this._wrapAnchor(node, lm);
+      anchor = this._wrapAnchor(node);
       if(anchor) return this.checkLink(anchor) ? anchor : null;
       node = node.parentNode;
     }
@@ -922,7 +917,7 @@ var gFlashGot = {
 ,
   downloadLink: function(dmName) {
     const sel = this.srcWindow.getSelection();
-    var link = !sel.isCollapsed && this._wrapAnchor(sel.anchorNode, gFlashGotService.lookupMethod)
+    var link = !sel.isCollapsed && this._wrapAnchor(sel.anchorNode)
       || this.findLinkAsc(this.hoverElement) || this.findLinkAsc(document.commandDispatcher.focusedElement);
     return link && this.download([link], gFlashGotService.OP_ONE, dmName);
   }
@@ -935,28 +930,21 @@ var gFlashGot = {
     links.startTime = startTime;
     return this.download(links, gFlashGotService.OP_SEL, dmName);
   }
-,
- WrappedCollection: function(coll) {
-  this.item = gFlashGotService.lookupMethod(coll, "item");
-  this.length = gFlashGotService.lookupMethod(coll, "length")();
- }
 ,
   collectAllLinks: function(doc, tagName) {
     var links = [];
     try {
       const includeImages = gFlashGotService.getPref("includeImages");
       if(tagName) {
-        var frames = new this.WrappedCollection(doc.getElementsByTagName(tagName));
-        const lm = gFlashGotService.lookupMethod;
+        var frames = doc.getElementsByTagName(tagName);
         var contentDocument;
         for(var j = frames.length; j-->0;) {
           try {
-            if((contentDocument = lm(frames.item(j), "contentDocument")())) {
+            if((contentDocument = frames[j].contentDocument)) {
               links = links.concat(
                 this.collectAllLinks(contentDocument));
             }
-          } catch(ex2) {
-          }
+          } catch(e) { dump(e + "\n"); }
         }
       } else {
         links = links.concat(this.getLinks(this.checkLink, includeImages, doc)
@@ -964,7 +952,7 @@ var gFlashGot = {
           ).concat(this.collectAllLinks(doc, "iframe"));
         this.addMediaLinks(links);
       }
-    } catch (e) {}
+    } catch (e) { dump(e + "\n"); }
     return links;
   }
 ,
@@ -1101,19 +1089,17 @@ var gFlashGot = {
       if(links && (len=links.length)) {
         const previewRX = /\d+.*\.(jpg|jpeg|png|gif|bmp)(\?|$)/i;
         const contentRX = /\d+.*\.[a-z0-9]{2,4}(\?|$)/i;
-        const lm = gFlashGotService.lookupMethod; 
-        var l, tag, url, imgs, i, iLen, i_item, imgSrc;
-        for(var j=0; j<len && ! (contentURL && previewURL); j++) {
-          l=links[j];
-          tag=l.tagName && l.tagName.toUpperCase();
-          url=l.href;
-          if(tag!="IMG" && contentRX.test(url)) {
-            contentURL=url;
-            if(tag=="A" && l.getElementsByTagName ) {
-              imgs=l.getElementsByTagName("img");
-              i_item=lm(imgs, "item");
-              for(i = 0, iLen = lm(imgs,"length")(); i < iLen; i++) {
-                imgSrc = lm(i_item(i),"src")();
+        var l, tag, url, imgs, i, iLen, imgSrc;
+        for(var  j = 0; j < len && !(contentURL && previewURL); j++) {
+          l = links[j];
+          tag = l.tagName && l.tagName.toUpperCase();
+          url = l.href;
+          if(tag !== "IMG" && contentRX.test(url)) {
+            contentURL = url;
+            if (tag === "A" && ("getElementsByTagName" in l)) {
+              imgs = l.getElementsByTagName("img");
+              for(i = 0, iLen = imgs.length; i < iLen; i++) {
+                imgSrc = imgs[i].src;
                 if(previewRX.test(imgSrc)) {
                   previewURL = imgSrc;
                   break;
@@ -1122,12 +1108,12 @@ var gFlashGot = {
             }
           }
         }
-        if( (!previewURL) && (tag=="img" || previewRX.test(url)) ) {
+        if( (!previewURL) && (tag === "IMG" || previewRX.test(url)) ) {
           previewURL=url;
         } 
       }
-      if(!previewURL) previewURL="";
-      if(previewURL && !contentURL) contentURL=previewURL;
+      if(!previewURL) previewURL = "";
+      if(previewURL && !contentURL) contentURL = previewURL;
     }
     window.openDialog("chrome://flashgot/content/flashgotGalleryBuilder.xul","_blank",
       "chrome,dialog,centerscreen,resizable",
