@@ -28,7 +28,7 @@ const NS_BINDING_ABORTED = 0x804b0002;
 const EXTENSION_ID = "{19503e42-ca3c-4c27-b1e2-9cdb2170ee34}";
 const EXTENSION_NAME = "FlashGot";
 const CHROME_NAME = "flashgot";
-const VERSION = "1.3.3";
+const VERSION = "1.4";
 const SERVICE_NAME = EXTENSION_NAME + " Service";
 const SERVICE_CTRID = "@maone.net/flashgot-service;1";
 const SERVICE_ID = "{2a55fc5c-7b31-4ee1-ab15-5ee2eb428cbe}";
@@ -664,7 +664,7 @@ fg = {
         continue;
       }
       try {
-        httpAuthManager.getAuthIdentity(uri.scheme, uri.host, uri.port < 0 ? (uri.scheme == "https" ? 443 : 80) : uri.port, null, null, uri.path, udom, uname, upwd);
+        httpAuthManager.getAuthIdentity(uri.scheme, uri.host, uri.port, null, null, uri.path, udom, uname, upwd);
       } catch(e) {
         
         if (uri.scheme !== "ftp" || !uri.username)
@@ -683,7 +683,7 @@ fg = {
         uname.value = uri.username;
         seen[realm] = upwd.value;
       }
-      l.userPass = uname.value + ":" + upwd.value;
+      l.userPass = encodeURIComponent(uname.value) + ":" + encodeURIComponent(upwd.value);
       fg.log("Authentication data " + l.userPass + " for " + l.href + " added.");
       l.href = uri.scheme + "://" + l.userPass + "@" + 
                uri.host + (uri.port < 0 ? "" : (":" + uri.port)) + uri.spec.substring(uri.prePath.length);
@@ -1243,13 +1243,6 @@ fg = {
     }
     this.log(cc.join(","));
   }
-,
-  _lookupMethod: null,
-  get lookupMethod() {
-    return this._lookupMethod?this._lookupMethod:(this._lookupMethod = 
-      (Components.utils && Components.utils.lookupMethod)
-        ? Components.utils.lookupMethod:Components.lookupMethod);
-  }
 ,
   showDMSReference: function() {
     this.getWindow().open("http://flashgot.net/dms","_blank");
